@@ -409,11 +409,7 @@ class APTRepoCheck(Check):
 
         # Check the base repos can handle destination codename
         for repo in self.base_repos:
-            if repo.dist == "buster/updates":
-                # special case, the repo syntax changed between LMDE 4 and LMDE 5
-                new_dist = "bullseye-security"
-            else:
-                new_dist = repo.dist.replace(ORIGIN_BASE_CODENAME, DESTINATION_BASE_CODENAME)
+            new_dist = repo.dist.replace(ORIGIN_BASE_CODENAME, DESTINATION_BASE_CODENAME)
             url = "%s/dists/%s/Release" % (repo.uri, new_dist)
             timestamp = self.get_url_last_modified(url)
             if timestamp == None:
@@ -576,6 +572,8 @@ class APTRemoveOrphansCheck(Check):
                     continue
                 if pkg.name.startswith("linux-headers-"):
                     continue
+                if pkg.name in NEW_ORPHANS_TO_KEEP:
+                    continue
                 if pkg.name in self.pre_upgrade_orphans:
                     print(f"Orphan {pkg.name} was already an orphan pre-upgrade, skipping it.")
                     continue
@@ -729,6 +727,8 @@ class SimulateUpgradeCheck(Check):
         download_size = fetcher.fetch_needed
         # additional space needed when all finished
         additional_space_needed = cache._depcache.usr_size
+        if additional_space_needed < 0:
+            additional_space_needed = 0.0
 
         # gather mount info so we calculate free space correctly.
         mounted = []
